/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This file was generated.
 *  with google-apis-code-generator 1.4.1 (build: 2013-08-01 15:32:38 UTC)
 *  on 2013-08-06 at 22:08:42 UTC 
 */

package com.google.api.services.datastore;

import com.google.api.client.googleapis.GoogleUtils;
import com.google.api.client.googleapis.services.AbstractGoogleClientRequest;
import com.google.api.client.googleapis.services.GoogleClientRequestInitializer;
import com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient;
import com.google.api.client.http.HttpRequestInitializer;
import com.google.api.client.http.HttpTransport;
import com.google.api.client.json.JsonFactory;
import com.google.api.client.json.JsonObjectParser;
import com.google.common.base.Preconditions;

/**
 * Service definition for Datastore (v1beta1).
 *
 * <p>
 * API for accessing Google Cloud Datastore.
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://developers.google.com/datastore/" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link DatastoreRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * <p>
 * Upgrade warning: this class now extends {@link AbstractGoogleJsonClient}, whereas in prior
 * version 1.8 it extended {@link com.google.api.client.googleapis.services.GoogleClient}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class Datastore extends AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    Preconditions.checkState(GoogleUtils.VERSION.equals("1.13.2-beta"),
        "You are currently running with version %s of google-api-client. " +
        "You need version 1.13.2-beta of google-api-client to run version " +
        "1.13.2-beta of the Google Cloud Datastore API library.", GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://www.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "datastore/v1beta1/datasets/";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   * @deprecated (scheduled to be removed in 1.13)
   */
  @Deprecated
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport
   * @param jsonFactory JSON factory
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public Datastore(HttpTransport transport, JsonFactory jsonFactory,
      HttpRequestInitializer httpRequestInitializer) {
    super(transport,
        jsonFactory,
        DEFAULT_ROOT_URL,
        DEFAULT_SERVICE_PATH,
        httpRequestInitializer,
        false);
  }

  /**
   * @param transport HTTP transport
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @param rootUrl root URL of the service
   * @param servicePath service path
   * @param jsonObjectParser JSON object parser
   * @param googleClientRequestInitializer Google request initializer or {@code null} for none
   * @param applicationName application name to be sent in the User-Agent header of requests or
   *        {@code null} for none
   * @param suppressPatternChecks whether discovery pattern checks should be suppressed on required
   *        parameters
   */
  Datastore(HttpTransport transport,
      HttpRequestInitializer httpRequestInitializer,
      String rootUrl,
      String servicePath,
      JsonObjectParser jsonObjectParser,
      GoogleClientRequestInitializer googleClientRequestInitializer,
      String applicationName,
      boolean suppressPatternChecks) {
    super(transport,
        httpRequestInitializer,
        rootUrl,
        servicePath,
        jsonObjectParser,
        googleClientRequestInitializer,
        applicationName,
        suppressPatternChecks);
  }

  @Override
  protected void initialize(AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the Datasets collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Datastore datastore = new Datastore(...);}
   *   {@code Datastore.Datasets.List request = datastore.datasets().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Datasets datasets() {
    return new Datasets();
  }

  /**
   * The "datasets" collection of methods.
   */
  public class Datasets {

    /**
     * Allocate IDs for incomplete keys (useful for referencing an entity before it is inserted).
     *
     * Create a request for the method "datasets.allocateIds".
     *
     * This request holds the parameters needed by the the datastore server.  After setting any optional
     * parameters, call the {@link AllocateIds#execute()} method to invoke the remote operation.
     *
     * @param datasetId Identifies the dataset.
     * @param content the {@link com.google.api.services.datastore.model.AllocateIdsRequest}
     * @return the request
     */
    public AllocateIds allocateIds(String datasetId, com.google.api.services.datastore.model.AllocateIdsRequest content) throws java.io.IOException {
      AllocateIds result = new AllocateIds(datasetId, content);
      initialize(result);
      return result;
    }

    public class AllocateIds extends DatastoreRequest<com.google.api.services.datastore.model.AllocateIdsResponse> {

      private static final String REST_PATH = "{datasetId}/allocateIds";

      /**
       * Allocate IDs for incomplete keys (useful for referencing an entity before it is inserted).
       *
       * Create a request for the method "datasets.allocateIds".
       *
       * This request holds the parameters needed by the the datastore server.  After setting any
       * optional parameters, call the {@link AllocateIds#execute()} method to invoke the remote
       * operation. <p> {@link AllocateIds#initialize(AbstractGoogleClientRequest)} must be called to
       * initialize this instance immediately after invoking the constructor. </p>
       *
       * @param datasetId Identifies the dataset.
       * @param content the {@link com.google.api.services.datastore.model.AllocateIdsRequest}
       * @since 1.13
       */
      protected AllocateIds(String datasetId, com.google.api.services.datastore.model.AllocateIdsRequest content) {
        super(Datastore.this, "POST", REST_PATH, content, com.google.api.services.datastore.model.AllocateIdsResponse.class);
        this.datasetId = Preconditions.checkNotNull(datasetId, "Required parameter datasetId must be specified.");
        set("alt", "json");
      }

      @Override
      public AllocateIds setAlt(String alt) {
        return (AllocateIds) super.setAlt(alt);
      }

      @Override
      public AllocateIds setFields(String fields) {
        return (AllocateIds) super.setFields(fields);
      }

      @Override
      public AllocateIds setKey(String key) {
        return (AllocateIds) super.setKey(key);
      }

      @Override
      public AllocateIds setOauthToken(String oauthToken) {
        return (AllocateIds) super.setOauthToken(oauthToken);
      }

      @Override
      public AllocateIds setPrettyPrint(Boolean prettyPrint) {
        return (AllocateIds) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public AllocateIds setQuotaUser(String quotaUser) {
        return (AllocateIds) super.setQuotaUser(quotaUser);
      }

      @Override
      public AllocateIds setUserIp(String userIp) {
        return (AllocateIds) super.setUserIp(userIp);
      }

      /** Identifies the dataset. */
      @com.google.api.client.util.Key
      private String datasetId;

      /** Identifies the dataset.
       */
      public String getDatasetId() {
        return datasetId;
      }

      /** Identifies the dataset. */
      public AllocateIds setDatasetId(String datasetId) {
        this.datasetId = datasetId;
        return this;
      }

    }
    /**
     * Begin a new transaction.
     *
     * Create a request for the method "datasets.beginTransaction".
     *
     * This request holds the parameters needed by the the datastore server.  After setting any optional
     * parameters, call the {@link BeginTransaction#execute()} method to invoke the remote operation.
     *
     * @param datasetId Identifies the dataset.
     * @param content the {@link com.google.api.services.datastore.model.BeginTransactionRequest}
     * @return the request
     */
    public BeginTransaction beginTransaction(String datasetId, com.google.api.services.datastore.model.BeginTransactionRequest content) throws java.io.IOException {
      BeginTransaction result = new BeginTransaction(datasetId, content);
      initialize(result);
      return result;
    }

    public class BeginTransaction extends DatastoreRequest<com.google.api.services.datastore.model.BeginTransactionResponse> {

      private static final String REST_PATH = "{datasetId}/beginTransaction";

      /**
       * Begin a new transaction.
       *
       * Create a request for the method "datasets.beginTransaction".
       *
       * This request holds the parameters needed by the the datastore server.  After setting any
       * optional parameters, call the {@link BeginTransaction#execute()} method to invoke the remote
       * operation. <p> {@link BeginTransaction#initialize(AbstractGoogleClientRequest)} must be called
       * to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param datasetId Identifies the dataset.
       * @param content the {@link com.google.api.services.datastore.model.BeginTransactionRequest}
       * @since 1.13
       */
      protected BeginTransaction(String datasetId, com.google.api.services.datastore.model.BeginTransactionRequest content) {
        super(Datastore.this, "POST", REST_PATH, content, com.google.api.services.datastore.model.BeginTransactionResponse.class);
        this.datasetId = Preconditions.checkNotNull(datasetId, "Required parameter datasetId must be specified.");
        set("alt", "json");
      }

      @Override
      public BeginTransaction setAlt(String alt) {
        return (BeginTransaction) super.setAlt(alt);
      }

      @Override
      public BeginTransaction setFields(String fields) {
        return (BeginTransaction) super.setFields(fields);
      }

      @Override
      public BeginTransaction setKey(String key) {
        return (BeginTransaction) super.setKey(key);
      }

      @Override
      public BeginTransaction setOauthToken(String oauthToken) {
        return (BeginTransaction) super.setOauthToken(oauthToken);
      }

      @Override
      public BeginTransaction setPrettyPrint(Boolean prettyPrint) {
        return (BeginTransaction) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public BeginTransaction setQuotaUser(String quotaUser) {
        return (BeginTransaction) super.setQuotaUser(quotaUser);
      }

      @Override
      public BeginTransaction setUserIp(String userIp) {
        return (BeginTransaction) super.setUserIp(userIp);
      }

      /** Identifies the dataset. */
      @com.google.api.client.util.Key
      private String datasetId;

      /** Identifies the dataset.
       */
      public String getDatasetId() {
        return datasetId;
      }

      /** Identifies the dataset. */
      public BeginTransaction setDatasetId(String datasetId) {
        this.datasetId = datasetId;
        return this;
      }

    }
    /**
     * Create, delete or modify some entities outside a transaction.
     *
     * Create a request for the method "datasets.blindWrite".
     *
     * This request holds the parameters needed by the the datastore server.  After setting any optional
     * parameters, call the {@link BlindWrite#execute()} method to invoke the remote operation.
     *
     * @param datasetId Identifies the dataset.
     * @param content the {@link com.google.api.services.datastore.model.BlindWriteRequest}
     * @return the request
     */
    public BlindWrite blindWrite(String datasetId, com.google.api.services.datastore.model.BlindWriteRequest content) throws java.io.IOException {
      BlindWrite result = new BlindWrite(datasetId, content);
      initialize(result);
      return result;
    }

    public class BlindWrite extends DatastoreRequest<com.google.api.services.datastore.model.BlindWriteResponse> {

      private static final String REST_PATH = "{datasetId}/blindWrite";

      /**
       * Create, delete or modify some entities outside a transaction.
       *
       * Create a request for the method "datasets.blindWrite".
       *
       * This request holds the parameters needed by the the datastore server.  After setting any
       * optional parameters, call the {@link BlindWrite#execute()} method to invoke the remote
       * operation. <p> {@link BlindWrite#initialize(AbstractGoogleClientRequest)} must be called to
       * initialize this instance immediately after invoking the constructor. </p>
       *
       * @param datasetId Identifies the dataset.
       * @param content the {@link com.google.api.services.datastore.model.BlindWriteRequest}
       * @since 1.13
       */
      protected BlindWrite(String datasetId, com.google.api.services.datastore.model.BlindWriteRequest content) {
        super(Datastore.this, "POST", REST_PATH, content, com.google.api.services.datastore.model.BlindWriteResponse.class);
        this.datasetId = Preconditions.checkNotNull(datasetId, "Required parameter datasetId must be specified.");
        set("alt", "json");
      }

      @Override
      public BlindWrite setAlt(String alt) {
        return (BlindWrite) super.setAlt(alt);
      }

      @Override
      public BlindWrite setFields(String fields) {
        return (BlindWrite) super.setFields(fields);
      }

      @Override
      public BlindWrite setKey(String key) {
        return (BlindWrite) super.setKey(key);
      }

      @Override
      public BlindWrite setOauthToken(String oauthToken) {
        return (BlindWrite) super.setOauthToken(oauthToken);
      }

      @Override
      public BlindWrite setPrettyPrint(Boolean prettyPrint) {
        return (BlindWrite) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public BlindWrite setQuotaUser(String quotaUser) {
        return (BlindWrite) super.setQuotaUser(quotaUser);
      }

      @Override
      public BlindWrite setUserIp(String userIp) {
        return (BlindWrite) super.setUserIp(userIp);
      }

      /** Identifies the dataset. */
      @com.google.api.client.util.Key
      private String datasetId;

      /** Identifies the dataset.
       */
      public String getDatasetId() {
        return datasetId;
      }

      /** Identifies the dataset. */
      public BlindWrite setDatasetId(String datasetId) {
        this.datasetId = datasetId;
        return this;
      }

    }
    /**
     * Commit a transaction, optionally creating, deleting or modifying some entities.
     *
     * Create a request for the method "datasets.commit".
     *
     * This request holds the parameters needed by the the datastore server.  After setting any optional
     * parameters, call the {@link Commit#execute()} method to invoke the remote operation.
     *
     * @param datasetId Identifies the dataset.
     * @param content the {@link com.google.api.services.datastore.model.CommitRequest}
     * @return the request
     */
    public Commit commit(String datasetId, com.google.api.services.datastore.model.CommitRequest content) throws java.io.IOException {
      Commit result = new Commit(datasetId, content);
      initialize(result);
      return result;
    }

    public class Commit extends DatastoreRequest<com.google.api.services.datastore.model.CommitResponse> {

      private static final String REST_PATH = "{datasetId}/commit";

      /**
       * Commit a transaction, optionally creating, deleting or modifying some entities.
       *
       * Create a request for the method "datasets.commit".
       *
       * This request holds the parameters needed by the the datastore server.  After setting any
       * optional parameters, call the {@link Commit#execute()} method to invoke the remote operation.
       * <p> {@link Commit#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param datasetId Identifies the dataset.
       * @param content the {@link com.google.api.services.datastore.model.CommitRequest}
       * @since 1.13
       */
      protected Commit(String datasetId, com.google.api.services.datastore.model.CommitRequest content) {
        super(Datastore.this, "POST", REST_PATH, content, com.google.api.services.datastore.model.CommitResponse.class);
        this.datasetId = Preconditions.checkNotNull(datasetId, "Required parameter datasetId must be specified.");
        set("alt", "json");
      }

      @Override
      public Commit setAlt(String alt) {
        return (Commit) super.setAlt(alt);
      }

      @Override
      public Commit setFields(String fields) {
        return (Commit) super.setFields(fields);
      }

      @Override
      public Commit setKey(String key) {
        return (Commit) super.setKey(key);
      }

      @Override
      public Commit setOauthToken(String oauthToken) {
        return (Commit) super.setOauthToken(oauthToken);
      }

      @Override
      public Commit setPrettyPrint(Boolean prettyPrint) {
        return (Commit) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Commit setQuotaUser(String quotaUser) {
        return (Commit) super.setQuotaUser(quotaUser);
      }

      @Override
      public Commit setUserIp(String userIp) {
        return (Commit) super.setUserIp(userIp);
      }

      /** Identifies the dataset. */
      @com.google.api.client.util.Key
      private String datasetId;

      /** Identifies the dataset.
       */
      public String getDatasetId() {
        return datasetId;
      }

      /** Identifies the dataset. */
      public Commit setDatasetId(String datasetId) {
        this.datasetId = datasetId;
        return this;
      }

    }
    /**
     * Look up some entities by key.
     *
     * Create a request for the method "datasets.lookup".
     *
     * This request holds the parameters needed by the the datastore server.  After setting any optional
     * parameters, call the {@link Lookup#execute()} method to invoke the remote operation.
     *
     * @param datasetId Identifies the dataset.
     * @param content the {@link com.google.api.services.datastore.model.LookupRequest}
     * @return the request
     */
    public Lookup lookup(String datasetId, com.google.api.services.datastore.model.LookupRequest content) throws java.io.IOException {
      Lookup result = new Lookup(datasetId, content);
      initialize(result);
      return result;
    }

    public class Lookup extends DatastoreRequest<com.google.api.services.datastore.model.LookupResponse> {

      private static final String REST_PATH = "{datasetId}/lookup";

      /**
       * Look up some entities by key.
       *
       * Create a request for the method "datasets.lookup".
       *
       * This request holds the parameters needed by the the datastore server.  After setting any
       * optional parameters, call the {@link Lookup#execute()} method to invoke the remote operation.
       * <p> {@link Lookup#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param datasetId Identifies the dataset.
       * @param content the {@link com.google.api.services.datastore.model.LookupRequest}
       * @since 1.13
       */
      protected Lookup(String datasetId, com.google.api.services.datastore.model.LookupRequest content) {
        super(Datastore.this, "POST", REST_PATH, content, com.google.api.services.datastore.model.LookupResponse.class);
        this.datasetId = Preconditions.checkNotNull(datasetId, "Required parameter datasetId must be specified.");
        set("alt", "json");
      }

      @Override
      public Lookup setAlt(String alt) {
        return (Lookup) super.setAlt(alt);
      }

      @Override
      public Lookup setFields(String fields) {
        return (Lookup) super.setFields(fields);
      }

      @Override
      public Lookup setKey(String key) {
        return (Lookup) super.setKey(key);
      }

      @Override
      public Lookup setOauthToken(String oauthToken) {
        return (Lookup) super.setOauthToken(oauthToken);
      }

      @Override
      public Lookup setPrettyPrint(Boolean prettyPrint) {
        return (Lookup) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Lookup setQuotaUser(String quotaUser) {
        return (Lookup) super.setQuotaUser(quotaUser);
      }

      @Override
      public Lookup setUserIp(String userIp) {
        return (Lookup) super.setUserIp(userIp);
      }

      /** Identifies the dataset. */
      @com.google.api.client.util.Key
      private String datasetId;

      /** Identifies the dataset.
       */
      public String getDatasetId() {
        return datasetId;
      }

      /** Identifies the dataset. */
      public Lookup setDatasetId(String datasetId) {
        this.datasetId = datasetId;
        return this;
      }

    }
    /**
     * Roll back a transaction.
     *
     * Create a request for the method "datasets.rollback".
     *
     * This request holds the parameters needed by the the datastore server.  After setting any optional
     * parameters, call the {@link Rollback#execute()} method to invoke the remote operation.
     *
     * @param datasetId Identifies the dataset.
     * @param content the {@link com.google.api.services.datastore.model.RollbackRequest}
     * @return the request
     */
    public Rollback rollback(String datasetId, com.google.api.services.datastore.model.RollbackRequest content) throws java.io.IOException {
      Rollback result = new Rollback(datasetId, content);
      initialize(result);
      return result;
    }

    public class Rollback extends DatastoreRequest<com.google.api.services.datastore.model.RollbackResponse> {

      private static final String REST_PATH = "{datasetId}/rollback";

      /**
       * Roll back a transaction.
       *
       * Create a request for the method "datasets.rollback".
       *
       * This request holds the parameters needed by the the datastore server.  After setting any
       * optional parameters, call the {@link Rollback#execute()} method to invoke the remote operation.
       * <p> {@link Rollback#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param datasetId Identifies the dataset.
       * @param content the {@link com.google.api.services.datastore.model.RollbackRequest}
       * @since 1.13
       */
      protected Rollback(String datasetId, com.google.api.services.datastore.model.RollbackRequest content) {
        super(Datastore.this, "POST", REST_PATH, content, com.google.api.services.datastore.model.RollbackResponse.class);
        this.datasetId = Preconditions.checkNotNull(datasetId, "Required parameter datasetId must be specified.");
        set("alt", "json");
      }

      @Override
      public Rollback setAlt(String alt) {
        return (Rollback) super.setAlt(alt);
      }

      @Override
      public Rollback setFields(String fields) {
        return (Rollback) super.setFields(fields);
      }

      @Override
      public Rollback setKey(String key) {
        return (Rollback) super.setKey(key);
      }

      @Override
      public Rollback setOauthToken(String oauthToken) {
        return (Rollback) super.setOauthToken(oauthToken);
      }

      @Override
      public Rollback setPrettyPrint(Boolean prettyPrint) {
        return (Rollback) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Rollback setQuotaUser(String quotaUser) {
        return (Rollback) super.setQuotaUser(quotaUser);
      }

      @Override
      public Rollback setUserIp(String userIp) {
        return (Rollback) super.setUserIp(userIp);
      }

      /** Identifies the dataset. */
      @com.google.api.client.util.Key
      private String datasetId;

      /** Identifies the dataset.
       */
      public String getDatasetId() {
        return datasetId;
      }

      /** Identifies the dataset. */
      public Rollback setDatasetId(String datasetId) {
        this.datasetId = datasetId;
        return this;
      }

    }
    /**
     * Query for entities.
     *
     * Create a request for the method "datasets.runQuery".
     *
     * This request holds the parameters needed by the the datastore server.  After setting any optional
     * parameters, call the {@link RunQuery#execute()} method to invoke the remote operation.
     *
     * @param datasetId Identifies the dataset.
     * @param content the {@link com.google.api.services.datastore.model.RunQueryRequest}
     * @return the request
     */
    public RunQuery runQuery(String datasetId, com.google.api.services.datastore.model.RunQueryRequest content) throws java.io.IOException {
      RunQuery result = new RunQuery(datasetId, content);
      initialize(result);
      return result;
    }

    public class RunQuery extends DatastoreRequest<com.google.api.services.datastore.model.RunQueryResponse> {

      private static final String REST_PATH = "{datasetId}/runQuery";

      /**
       * Query for entities.
       *
       * Create a request for the method "datasets.runQuery".
       *
       * This request holds the parameters needed by the the datastore server.  After setting any
       * optional parameters, call the {@link RunQuery#execute()} method to invoke the remote operation.
       * <p> {@link RunQuery#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param datasetId Identifies the dataset.
       * @param content the {@link com.google.api.services.datastore.model.RunQueryRequest}
       * @since 1.13
       */
      protected RunQuery(String datasetId, com.google.api.services.datastore.model.RunQueryRequest content) {
        super(Datastore.this, "POST", REST_PATH, content, com.google.api.services.datastore.model.RunQueryResponse.class);
        this.datasetId = Preconditions.checkNotNull(datasetId, "Required parameter datasetId must be specified.");
        set("alt", "json");
      }

      @Override
      public RunQuery setAlt(String alt) {
        return (RunQuery) super.setAlt(alt);
      }

      @Override
      public RunQuery setFields(String fields) {
        return (RunQuery) super.setFields(fields);
      }

      @Override
      public RunQuery setKey(String key) {
        return (RunQuery) super.setKey(key);
      }

      @Override
      public RunQuery setOauthToken(String oauthToken) {
        return (RunQuery) super.setOauthToken(oauthToken);
      }

      @Override
      public RunQuery setPrettyPrint(Boolean prettyPrint) {
        return (RunQuery) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public RunQuery setQuotaUser(String quotaUser) {
        return (RunQuery) super.setQuotaUser(quotaUser);
      }

      @Override
      public RunQuery setUserIp(String userIp) {
        return (RunQuery) super.setUserIp(userIp);
      }

      /** Identifies the dataset. */
      @com.google.api.client.util.Key
      private String datasetId;

      /** Identifies the dataset.
       */
      public String getDatasetId() {
        return datasetId;
      }

      /** Identifies the dataset. */
      public RunQuery setDatasetId(String datasetId) {
        this.datasetId = datasetId;
        return this;
      }

    }

  }

  /**
   * Builder for {@link Datastore}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport
     * @param jsonFactory JSON factory
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(HttpTransport transport, JsonFactory jsonFactory,
        HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          false);
    }

    /** Builds a new instance of {@link Datastore}. */
    @Override
    public Datastore build() {
      return new Datastore(getTransport(),
          getHttpRequestInitializer(),
          getRootUrl(),
          getServicePath(),
          getObjectParser(),
          getGoogleClientRequestInitializer(),
          getApplicationName(),
          getSuppressPatternChecks());
    }

    @Override
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    public Builder setHttpRequestInitializer(HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    /**
     * Set the {@link DatastoreRequestInitializer}.
     *
     * @since 1.12
     */
    public Builder setDatastoreRequestInitializer(
        DatastoreRequestInitializer datastoreRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(datastoreRequestInitializer);
    }

    @Override
    public Builder setGoogleClientRequestInitializer(
        GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }
  }
}
